/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { PreventableEvent } from "@progress/kendo-angular-common";
/**
 * Represents the arguments for the PDFViewer `download` event. The event fires when the user clicks the **Download** tool. Canceling the event prevents the download.
 */
export class PDFViewerDownloadEvent extends PreventableEvent {
    /**
     * Provides the Blob object to be saved.
     */
    blob;
    /**
     * Provides the file name for saving.
     */
    fileName;
    /**
     * Provides the save options.
     */
    saveOptions;
    /**
     * Represents the loaded `PDF.js` document, its pages, and their DOM element wrapper.
     */
    context;
    /**
     * @hidden
     */
    constructor(blob, fileName, saveOptions, context) {
        super();
        this.blob = blob;
        this.fileName = fileName;
        this.saveOptions = saveOptions;
        this.context = context;
    }
}
