/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { Component, ElementRef, HostBinding, Input, Renderer2 } from '@angular/core';
import { focusableSelector } from '@progress/kendo-angular-common';
import { Subscription } from 'rxjs';
import * as i0 from "@angular/core";
/**
 * @hidden
 */
export class ToolbarInputWrapperComponent {
    host;
    renderer;
    toolbarTool;
    hostClass = true;
    subs = new Subscription();
    constructor(host, renderer) {
        this.host = host;
        this.renderer = renderer;
    }
    ngAfterViewInit() {
        this.subs.add(this.renderer.listen(this.host.nativeElement, 'keydown.enter', () => {
            if (this.toolbarTool.focus) {
                this.toolbarTool.focus();
            }
            else if (this.toolbarTool.element) {
                this.toolbarTool.element.nativeElement.setAttribute('tabindex', '0');
                this.toolbarTool.element.nativeElement.focus();
            }
        }));
        this.subs.add(this.renderer.listen(this.host.nativeElement, 'blur', () => this.host.nativeElement.querySelectorAll(focusableSelector).forEach(el => el.setAttribute('tabindex', '-1'))));
        this.subs.add(this.renderer.listen(this.host.nativeElement, 'keydown.escape', () => {
            if (this.toolbarTool.blur) {
                this.toolbarTool.blur();
            }
            else if (this.toolbarTool.element) {
                this.toolbarTool.element.nativeElement.setAttribute('tabindex', '-1');
                this.toolbarTool.element.nativeElement.blur();
            }
            this.host.nativeElement.focus();
        }));
    }
    ngOnDestroy() {
        this.subs.unsubscribe();
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: ToolbarInputWrapperComponent, deps: [{ token: i0.ElementRef }, { token: i0.Renderer2 }], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.12", type: ToolbarInputWrapperComponent, isStandalone: true, selector: "kendo-toolbar-input-wrapper", inputs: { toolbarTool: "toolbarTool" }, host: { properties: { "class.k-toolbar-item": "this.hostClass" } }, ngImport: i0, template: `
        <ng-content></ng-content>
    `, isInline: true });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: ToolbarInputWrapperComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'kendo-toolbar-input-wrapper',
                    template: `
        <ng-content></ng-content>
    `,
                    standalone: true
                }]
        }], ctorParameters: function () { return [{ type: i0.ElementRef }, { type: i0.Renderer2 }]; }, propDecorators: { toolbarTool: [{
                type: Input
            }], hostClass: [{
                type: HostBinding,
                args: ['class.k-toolbar-item']
            }] } });
