/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { Component, ElementRef, EventEmitter, HostBinding, HostListener, Input, Output, ViewChild } from '@angular/core';
import { TextBoxComponent, TextBoxSuffixTemplateDirective } from '@progress/kendo-angular-inputs';
import { LocalizationService } from '@progress/kendo-angular-l10n';
import { arrowDownIcon, arrowUpIcon, convertLowercaseIcon, xIcon } from '@progress/kendo-svg-icons';
import { ButtonComponent } from '@progress/kendo-angular-buttons';
import * as i0 from "@angular/core";
import * as i1 from "@progress/kendo-angular-l10n";
/**
 * @hidden
 */
export class PDFViewerSearchComponent {
    localization;
    textbox;
    closeButton;
    ariaRole = 'dialog';
    onEscape() {
        this.close.emit();
    }
    matches;
    currentMatch;
    searchChange = new EventEmitter();
    prevMatch = new EventEmitter();
    nextMatch = new EventEmitter();
    close = new EventEmitter();
    convertLowercaseIcon = convertLowercaseIcon;
    arrowUpIcon = arrowUpIcon;
    arrowDownIcon = arrowDownIcon;
    xIcon = xIcon;
    value = null;
    matchCase = false;
    constructor(localization) {
        this.localization = localization;
    }
    ngAfterViewInit() {
        this.textbox.focus();
    }
    messageFor(key) {
        return this.localization.get(key);
    }
    onShiftTab(e) {
        if (e.target.matches('.k-input-inner')) {
            e.preventDefault();
            this.closeButton.nativeElement.focus();
        }
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: PDFViewerSearchComponent, deps: [{ token: i1.LocalizationService }], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.12", type: PDFViewerSearchComponent, isStandalone: true, selector: "[kendoPDFViewerSearch]", inputs: { matches: "matches", currentMatch: "currentMatch" }, outputs: { searchChange: "searchChange", prevMatch: "prevMatch", nextMatch: "nextMatch", close: "close" }, host: { listeners: { "keydown.escape": "onEscape()" }, properties: { "attr.role": "this.ariaRole" } }, viewQueries: [{ propertyName: "textbox", first: true, predicate: ["textbox"], descendants: true }, { propertyName: "closeButton", first: true, predicate: ["closeButton"], descendants: true, read: ElementRef }], ngImport: i0, template: `
        <kendo-textbox
            #textbox
            [placeholder]="messageFor('searchInputPlaceholder')"
            [value]="value"
            (valueChange)="value = $event; searchChange.emit({text: $event, matchCase})"
            (keydown.shift.tab)="onShiftTab($event)">
            <ng-template kendoTextBoxSuffixTemplate>
                <button
                    type="button"
                    kendoButton
                    [attr.title]="messageFor('searchMatchCaseTitle')"
                    fillMode="flat"
                    [togglable]="true"
                    (click)="matchCase = !matchCase; searchChange.emit({text: value, matchCase})"
                    icon="convert-lowercase"
                    [svgIcon]="convertLowercaseIcon"></button>
            </ng-template>
        </kendo-textbox>
        <span class="k-search-matches">
            <span>{{currentMatch}}</span> {{messageFor('searchMatchesOf')}} <span>{{matches}}</span>
        </span>
        <button
            type="button"
            kendoButton
            [attr.title]="messageFor('searchPreviousMatchTitle')"
            fillMode="flat"
            [disabled]="matches === 0"
            (click)="prevMatch.emit()"
            icon='arrow-up'
            [svgIcon]="arrowUpIcon"></button>
        <button
            type="button"
            kendoButton
            [attr.title]="messageFor('searchNextMatchTitle')"
            fillMode="flat"
            [disabled]="matches === 0"
            (click)="nextMatch.emit()"
            icon='arrow-down'
            [svgIcon]="arrowDownIcon"></button>
        <button
            type="button"
            #closeButton
            kendoButton
            [attr.title]="messageFor('searchCloseTitle')"
            fillMode="flat"
            (click)="close.emit()"
            (keydown.tab)="$event.preventDefault(); textbox.focus();"
            icon='x'
            [svgIcon]="xIcon"></button>
    `, isInline: true, dependencies: [{ kind: "component", type: TextBoxComponent, selector: "kendo-textbox", inputs: ["focusableId", "title", "type", "disabled", "readonly", "tabindex", "value", "selectOnFocus", "showSuccessIcon", "showErrorIcon", "clearButton", "successIcon", "successSvgIcon", "errorIcon", "errorSvgIcon", "clearButtonIcon", "clearButtonSvgIcon", "size", "rounded", "fillMode", "tabIndex", "placeholder", "maxlength", "inputAttributes"], outputs: ["valueChange", "inputFocus", "inputBlur", "focus", "blur"], exportAs: ["kendoTextBox"] }, { kind: "directive", type: TextBoxSuffixTemplateDirective, selector: "[kendoTextBoxSuffixTemplate]", inputs: ["showSeparator"] }, { kind: "component", type: ButtonComponent, selector: "button[kendoButton]", inputs: ["arrowIcon", "toggleable", "togglable", "selected", "tabIndex", "imageUrl", "iconClass", "icon", "disabled", "size", "rounded", "fillMode", "themeColor", "svgIcon", "primary", "look"], outputs: ["selectedChange", "click"], exportAs: ["kendoButton"] }] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: PDFViewerSearchComponent, decorators: [{
            type: Component,
            args: [{
                    selector: '[kendoPDFViewerSearch]',
                    template: `
        <kendo-textbox
            #textbox
            [placeholder]="messageFor('searchInputPlaceholder')"
            [value]="value"
            (valueChange)="value = $event; searchChange.emit({text: $event, matchCase})"
            (keydown.shift.tab)="onShiftTab($event)">
            <ng-template kendoTextBoxSuffixTemplate>
                <button
                    type="button"
                    kendoButton
                    [attr.title]="messageFor('searchMatchCaseTitle')"
                    fillMode="flat"
                    [togglable]="true"
                    (click)="matchCase = !matchCase; searchChange.emit({text: value, matchCase})"
                    icon="convert-lowercase"
                    [svgIcon]="convertLowercaseIcon"></button>
            </ng-template>
        </kendo-textbox>
        <span class="k-search-matches">
            <span>{{currentMatch}}</span> {{messageFor('searchMatchesOf')}} <span>{{matches}}</span>
        </span>
        <button
            type="button"
            kendoButton
            [attr.title]="messageFor('searchPreviousMatchTitle')"
            fillMode="flat"
            [disabled]="matches === 0"
            (click)="prevMatch.emit()"
            icon='arrow-up'
            [svgIcon]="arrowUpIcon"></button>
        <button
            type="button"
            kendoButton
            [attr.title]="messageFor('searchNextMatchTitle')"
            fillMode="flat"
            [disabled]="matches === 0"
            (click)="nextMatch.emit()"
            icon='arrow-down'
            [svgIcon]="arrowDownIcon"></button>
        <button
            type="button"
            #closeButton
            kendoButton
            [attr.title]="messageFor('searchCloseTitle')"
            fillMode="flat"
            (click)="close.emit()"
            (keydown.tab)="$event.preventDefault(); textbox.focus();"
            icon='x'
            [svgIcon]="xIcon"></button>
    `,
                    standalone: true,
                    imports: [TextBoxComponent, TextBoxSuffixTemplateDirective, ButtonComponent]
                }]
        }], ctorParameters: function () { return [{ type: i1.LocalizationService }]; }, propDecorators: { textbox: [{
                type: ViewChild,
                args: ['textbox']
            }], closeButton: [{
                type: ViewChild,
                args: ['closeButton', { read: ElementRef }]
            }], ariaRole: [{
                type: HostBinding,
                args: ['attr.role']
            }], onEscape: [{
                type: HostListener,
                args: ['keydown.escape']
            }], matches: [{
                type: Input
            }], currentMatch: [{
                type: Input
            }], searchChange: [{
                type: Output
            }], prevMatch: [{
                type: Output
            }], nextMatch: [{
                type: Output
            }], close: [{
                type: Output
            }] } });
