/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { Directive, ElementRef, Renderer2 } from '@angular/core';
import { ToolbarNavigationService } from './toolbar-navigation.service';
import { Keys, focusableSelector } from '@progress/kendo-angular-common';
import * as i0 from "@angular/core";
import * as i1 from "./toolbar-navigation.service";
const controller = new AbortController();
const { signal } = controller;
/**
 * @hidden
 */
export class ToolbarFocusableDirective {
    host;
    navigationService;
    renderer;
    constructor(host, navigationService, renderer) {
        this.host = host;
        this.navigationService = navigationService;
        this.renderer = renderer;
        navigationService.register(this);
    }
    ngAfterViewInit() {
        const element = this.host.nativeElement;
        this.renderer.setAttribute(element, 'tabindex', this.navigationService.isActive(this) ? '0' : '-1');
        element.addEventListener('keydown', (e) => {
            const targetsSelf = e.target === element;
            const isLeftArrow = e.keyCode === Keys.ArrowLeft;
            const isRightArrow = e.keyCode === Keys.ArrowRight;
            const isArrow = isLeftArrow || isRightArrow;
            if (!targetsSelf || !isArrow) {
                return;
            }
            this.renderer.setAttribute(element, 'tabindex', '-1');
            element.querySelectorAll(focusableSelector).forEach(el => {
                this.renderer.setAttribute(el, 'tabindex', '-1');
            });
            if (isRightArrow) {
                this.navigationService.move('right');
            }
            else if (isLeftArrow) {
                this.navigationService.move('left');
            }
        }, { signal, capture: true });
        element.addEventListener('click', () => {
            this.navigationService.setActiveIndex(this);
        }, { signal, capture: true });
    }
    ngOnDestroy() {
        controller.abort();
        this.navigationService.unregister(this);
    }
    activate() {
        const element = this.host.nativeElement;
        this.renderer.setAttribute(element, 'tabindex', '0');
        element.focus();
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: ToolbarFocusableDirective, deps: [{ token: i0.ElementRef }, { token: i1.ToolbarNavigationService }, { token: i0.Renderer2 }], target: i0.ɵɵFactoryTarget.Directive });
    static ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "16.2.12", type: ToolbarFocusableDirective, isStandalone: true, selector: "[kendoPDFViewerToolbarFocusable]", ngImport: i0 });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: ToolbarFocusableDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[kendoPDFViewerToolbarFocusable]',
                    standalone: true
                }]
        }], ctorParameters: function () { return [{ type: i0.ElementRef }, { type: i1.ToolbarNavigationService }, { type: i0.Renderer2 }]; } });
