/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { Injectable } from '@angular/core';
import { LocalizationService } from '@progress/kendo-angular-l10n';
import * as i0 from "@angular/core";
import * as i1 from "@progress/kendo-angular-l10n";
/**
 * @hidden
 */
export class ToolbarNavigationService {
    localizationService;
    focusableTools = [];
    currentFocusIndex = 0;
    constructor(localizationService) {
        this.localizationService = localizationService;
    }
    register(tool) {
        if (!this.focusableTools.some(el => el === tool)) {
            this.focusableTools.push(tool);
        }
    }
    unregister(tool) {
        this.currentFocusIndex = 0;
        this.focusableTools = this.focusableTools.filter(el => el !== tool);
    }
    isActive(focusable) {
        return this.focusableTools[this.currentFocusIndex] === focusable;
    }
    setActiveIndex(tool) {
        this.currentFocusIndex = Math.max(this.focusableTools.indexOf(tool), 0);
    }
    move(direction) {
        let delta = direction === 'right' ? 1 : -1;
        if (this.localizationService.rtl) {
            delta = -delta;
        }
        this.currentFocusIndex += delta;
        if (this.currentFocusIndex < 0) {
            this.currentFocusIndex = this.focusableTools.length - 1;
        }
        else if (this.currentFocusIndex >= this.focusableTools.length) {
            this.currentFocusIndex = 0;
        }
        this.focusableTools[this.currentFocusIndex].activate();
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: ToolbarNavigationService, deps: [{ token: i1.LocalizationService }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: ToolbarNavigationService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: ToolbarNavigationService, decorators: [{
            type: Injectable
        }], ctorParameters: function () { return [{ type: i1.LocalizationService }]; } });
