/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
/* eslint-disable @typescript-eslint/no-empty-function */
import { Component, ElementRef, EventEmitter, HostBinding, Input, Output, ViewChild } from '@angular/core';
import { LocalizationService } from '@progress/kendo-angular-l10n';
import { PagerComponent, CustomMessagesComponent } from '@progress/kendo-angular-pager';
import { searchIcon, zoomInIcon, zoomOutIcon, pointerIcon, handIcon, folderOpenIcon, downloadIcon, printIcon } from '@progress/kendo-svg-icons';
import { ToolbarNavigationService } from './toolbar-navigation.service';
import { ComboBoxComponent, ItemTemplateDirective } from '@progress/kendo-angular-dropdowns';
import { ToolbarComboBoxDirective } from './toolbar-combobox.directive';
import { ButtonComponent, ButtonGroupComponent } from '@progress/kendo-angular-buttons';
import { ToolbarFocusableDirective } from './toolbar-focusable.directive';
import { ToolbarInputWrapperComponent } from './input-wrapper.component';
import { NgFor, NgSwitch, NgSwitchCase, NgIf } from '@angular/common';
import { map } from 'rxjs/operators';
import * as i0 from "@angular/core";
import * as i1 from "@progress/kendo-angular-l10n";
import * as i2 from "./toolbar-navigation.service";
/**
 * @hidden
 */
export class ToolbarComponent {
    localization;
    navigationService;
    toolbarClasses = true;
    fileSelectEl;
    zoomLevel = {
        text: '125%',
        displayValue: '125%',
        value: 1.25
    };
    calculatedComboBoxValue = {
        text: 'Fit to width',
        displayValue: null,
        value: null
    };
    skip = 0;
    pageSize = 1;
    total;
    zoomInDisabled;
    zoomOutDisabled;
    disabledTools;
    zoomLevelChooserValue;
    zoomOptionsData;
    pagesContainerId;
    tools;
    fileSelect = new EventEmitter();
    fileSelectStart = new EventEmitter();
    fileSelectError = new EventEmitter();
    download = new EventEmitter();
    selectionEnabled = new EventEmitter();
    panningEnabled = new EventEmitter();
    pageChange = new EventEmitter();
    zoomIn = new EventEmitter();
    zoomOut = new EventEmitter();
    zoomLevelChange = new EventEmitter();
    print = new EventEmitter();
    search = new EventEmitter();
    zoomInIcon = zoomInIcon;
    zoomOutIcon = zoomOutIcon;
    handIcon = handIcon;
    pointerIcon = pointerIcon;
    searchIcon = searchIcon;
    folderOpenIcon = folderOpenIcon;
    downloadIcon = downloadIcon;
    printIcon = printIcon;
    pagerType = 'input';
    constructor(localization, navigationService) {
        this.localization = localization;
        this.navigationService = navigationService;
    }
    messageFor(key) {
        return this.localization.get(key);
    }
    onFileSelect(e) {
        const file = e.target.files[0];
        this.fileSelectStart.emit();
        if (file) {
            const reader = new FileReader();
            reader.onload = (e) => {
                const data = e.target.result;
                this.fileSelect.emit(data);
            };
            reader.onerror = (e) => {
                this.fileSelectError.emit(e);
            };
            reader.readAsDataURL(file);
        }
    }
    onZoomLevelChooserValueChange(zoomLevel) {
        this.zoomLevelChange.emit(zoomLevel);
    }
    focus() {
        this.navigationService.focusableTools[this.navigationService.currentFocusIndex].activate();
    }
    valueNormalizer = (text) => text.pipe(map((value) => {
        const parsedValue = parseFloat(value);
        const newValue = Number.isNaN(parsedValue) ? 1 : parsedValue / 100;
        return {
            value: newValue,
            displayValue: `${Math.round(newValue * 100)}%`,
            text: `${Math.round(newValue * 100)}%`
        };
    }));
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: ToolbarComponent, deps: [{ token: i1.LocalizationService }, { token: i2.ToolbarNavigationService }], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.12", type: ToolbarComponent, isStandalone: true, selector: "[kendoPDFViewerToolbar]", inputs: { zoomLevel: "zoomLevel", calculatedComboBoxValue: "calculatedComboBoxValue", skip: "skip", pageSize: "pageSize", total: "total", zoomInDisabled: "zoomInDisabled", zoomOutDisabled: "zoomOutDisabled", disabledTools: "disabledTools", zoomLevelChooserValue: "zoomLevelChooserValue", zoomOptionsData: "zoomOptionsData", pagesContainerId: "pagesContainerId", tools: "tools" }, outputs: { fileSelect: "fileSelect", fileSelectStart: "fileSelectStart", fileSelectError: "fileSelectError", download: "download", selectionEnabled: "selectionEnabled", panningEnabled: "panningEnabled", pageChange: "pageChange", zoomIn: "zoomIn", zoomOut: "zoomOut", zoomLevelChange: "zoomLevelChange", print: "print", search: "search" }, host: { properties: { "class.k-toolbar": "this.toolbarClasses", "class.k-toolbar-md": "this.toolbarClasses", "class.k-toolbar-flat": "this.toolbarClasses" } }, providers: [ToolbarNavigationService], viewQueries: [{ propertyName: "fileSelectEl", first: true, predicate: ["fileSelectEl"], descendants: true }], ngImport: i0, template: `
        <ng-container *ngFor="let tool of tools">
            <ng-container [ngSwitch]="tool">
                <kendo-toolbar-input-wrapper
                    *ngSwitchCase="'pager'"
                    kendoPDFViewerToolbarFocusable
                    [toolbarTool]="pager">
                    <kendo-datapager
                        #pager
                        [attr.aria-controls]="pagesContainerId"
                        [attr.aria-label]="messageFor('page') + ' ' + (skip + 1) + ' ' + messageFor('of') + total"
                        [class.k-disabled]="disabledTools"
                        [navigable]="true"
                        [pageSize]="pageSize"
                        [skip]="skip"
                        [total]="total"
                        [pageSizeValues]="false"
                        [info]="false"
                        [type]="pagerType"
                        (pageChange)="pageChange.emit($event)">
                        <kendo-datapager-messages
                            [firstPage]="messageFor('pagerFirstPage')"
                            [previousPage]="messageFor('pagerPreviousPage')"
                            [nextPage]="messageFor('pagerNextPage')"
                            [lastPage]="messageFor('pagerLastPage')"
                            [inputLabel]="messageFor('pagerInputLabel')"
                            [pageNumberInputTitle]="messageFor('pagerInputTitle')"
                            [of]="messageFor('pagerOf')"
                            [page]="messageFor('pagerPage')"></kendo-datapager-messages>
                    </kendo-datapager>
                </kendo-toolbar-input-wrapper>
                <span
                    *ngSwitchCase="'spacer'"
                    class="k-spacer"></span>
                <kendo-buttongroup
                    *ngSwitchCase="'zoomInOut'"
                    [attr.aria-controls]="pagesContainerId"
                    class="k-button-group-flat k-toolbar-button-group"
                    [navigable]="false">
                    <button
                        type="button"
                        kendoButton
                        fillMode="flat"
                        kendoPDFViewerToolbarFocusable
                        icon="zoom-out"
                        [disabled]="disabledTools || zoomOutDisabled"
                        [svgIcon]="zoomOutIcon"
                        [attr.title]="messageFor('zoomOutTitle')"
                        [attr.aria-label]="messageFor('zoomOutTitle')"
                        (click)="zoomOut.emit()"></button>
                    <button
                        type="button"
                        kendoButton
                        fillMode="flat"
                        kendoPDFViewerToolbarFocusable
                        icon="zoom-in"
                        [disabled]="disabledTools || zoomInDisabled"
                        [svgIcon]="zoomInIcon"
                        [attr.title]="messageFor('zoomInTitle')"
                        [attr.aria-label]="messageFor('zoomInTitle')"
                        (click)="zoomIn.emit()"></button>
                </kendo-buttongroup>
                <kendo-toolbar-input-wrapper
                    *ngSwitchCase="'zoom'"
                    kendoPDFViewerToolbarFocusable
                    [toolbarTool]="combobox">
                    <kendo-combobox
                        #combobox
                        kendoPDFViewerComboBox
                        class="k-toolbar-combobox"
                        fillMode="flat"
                        [attr.aria-controls]="pagesContainerId"
                        [tabindex]="-1"
                        [data]="zoomOptionsData"
                        [disabled]="disabledTools"
                        [placeholder]="messageFor('zoomInputPlaceholder')"
                        textField="displayValue"
                        valueField="id"
                        [value]="zoomLevelChooserValue"
                        [allowCustom]="true"
                        [valueNormalizer]="valueNormalizer"
                        [clearButton]="false"
                        (valueChange)="onZoomLevelChooserValueChange($event)">
                        <ng-template kendoComboBoxItemTemplate let-dataItem>
                            {{ dataItem.type ? messageFor('f' + dataItem.type.slice(1)) : dataItem.text }}
                        </ng-template>
                    </kendo-combobox>
                </kendo-toolbar-input-wrapper>
                <kendo-buttongroup
                    *ngSwitchCase="'selection'"
                    [attr.aria-controls]="pagesContainerId"
                    [navigable]="false"
                    class="k-button-group-flat k-toolbar-button-group"
                    selection="single">
                    <button
                        type="button"
                        kendoButton
                        kendoPDFViewerToolbarFocusable
                        fillMode="flat"
                        icon="pointer"
                        [toggleable]="true"
                        [svgIcon]="pointerIcon"
                        [attr.title]="messageFor('selectionTitle')"
                        [attr.aria-label]="messageFor('selectionTitle')"
                        (click)="selectionEnabled.emit()"></button>
                    <button
                        type="button"
                        kendoButton
                        kendoPDFViewerToolbarFocusable
                        fillMode="flat"
                        icon="hand"
                        [svgIcon]="handIcon"
                        [toggleable]="true"
                        [selected]="true"
                        [attr.title]="messageFor('panningTitle')"
                        [attr.aria-label]="messageFor('panningTitle')"
                        (click)="panningEnabled.emit()"></button>
                </kendo-buttongroup>
                <button
                    *ngSwitchCase="'search'"
                    type="button"
                    kendoPDFViewerToolbarFocusable
                    kendoButton
                    class="k-toolbar-button"
                    fillMode="flat"
                    icon="search"
                    [disabled]="disabledTools"
                    [attr.title]="messageFor('searchTitle')"
                    [attr.aria-label]="messageFor('searchTitle')"
                    aria-haspopup="dialog"
                    [svgIcon]="searchIcon"
                    (click)="search.emit()"></button>
                <button
                    *ngSwitchCase="'open'"
                    type="button"
                    fillMode="flat"
                    kendoPDFViewerToolbarFocusable
                    kendoButton
                    class="k-toolbar-button"
                    fillMode="flat"
                    icon="folder-open"
                    [svgIcon]="folderOpenIcon"
                    [attr.title]="messageFor('openTitle')"
                    [attr.aria-label]="messageFor('openTitle')"
                    [attr.aria-controls]="pagesContainerId"
                    (click)="fileSelectEl?.nativeElement.click()">
                </button>
                <button
                    *ngSwitchCase="'download'"
                    type="button"
                    fillMode="flat"
                    kendoPDFViewerToolbarFocusable
                    kendoButton
                    class="k-toolbar-button"
                    icon="download"
                    [svgIcon]="downloadIcon"
                    [disabled]="disabledTools"
                    [attr.title]="messageFor('downloadTitle')"
                    [attr.aria-label]="messageFor('downloadTitle')"
                    (click)="download.emit()"></button>
                <button
                    *ngSwitchCase="'print'"
                    type="button"
                    fillMode="flat"
                    kendoPDFViewerToolbarFocusable
                    kendoButton
                    class="k-toolbar-button"
                    icon="print"
                    [svgIcon]="printIcon"
                    [disabled]="disabledTools"
                    [attr.title]="messageFor('printTitle')"
                    [attr.aria-label]="messageFor('printTitle')"
                    (click)="print.emit()"></button>
            </ng-container>
        </ng-container>
        <input
            #fileSelectEl
            *ngIf="tools?.indexOf('open') > -1;"
            type="file"
            [style.display]="'none'"
            aria-hidden="true"
            accept=".pdf, .PDF"
            (change)="onFileSelect($event)" />
    `, isInline: true, dependencies: [{ kind: "directive", type: NgFor, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { kind: "directive", type: NgSwitch, selector: "[ngSwitch]", inputs: ["ngSwitch"] }, { kind: "directive", type: NgSwitchCase, selector: "[ngSwitchCase]", inputs: ["ngSwitchCase"] }, { kind: "component", type: ToolbarInputWrapperComponent, selector: "kendo-toolbar-input-wrapper", inputs: ["toolbarTool"] }, { kind: "directive", type: ToolbarFocusableDirective, selector: "[kendoPDFViewerToolbarFocusable]" }, { kind: "component", type: PagerComponent, selector: "kendo-datapager, kendo-pager", inputs: ["externalTemplate", "total", "skip", "pageSize", "buttonCount", "info", "type", "pageSizeValues", "previousNext", "navigable", "size", "responsive", "adaptiveMode"], outputs: ["pageChange", "pageSizeChange", "pagerInputVisibilityChange", "pageTextVisibilityChange", "itemsTextVisibilityChange"], exportAs: ["kendoDataPager", "kendoPager"] }, { kind: "component", type: CustomMessagesComponent, selector: "kendo-datapager-messages, kendo-pager-messages" }, { kind: "component", type: ButtonGroupComponent, selector: "kendo-buttongroup", inputs: ["disabled", "selection", "width", "tabIndex", "navigable"], outputs: ["navigate"], exportAs: ["kendoButtonGroup"] }, { kind: "component", type: ButtonComponent, selector: "button[kendoButton]", inputs: ["arrowIcon", "toggleable", "togglable", "selected", "tabIndex", "imageUrl", "iconClass", "icon", "disabled", "size", "rounded", "fillMode", "themeColor", "svgIcon", "primary", "look"], outputs: ["selectedChange", "click"], exportAs: ["kendoButton"] }, { kind: "component", type: ComboBoxComponent, selector: "kendo-combobox", inputs: ["icon", "svgIcon", "inputAttributes", "showStickyHeader", "focusableId", "allowCustom", "data", "value", "textField", "valueField", "valuePrimitive", "valueNormalizer", "placeholder", "adaptiveMode", "adaptiveTitle", "adaptiveSubtitle", "popupSettings", "listHeight", "loading", "suggest", "clearButton", "disabled", "itemDisabled", "readonly", "tabindex", "tabIndex", "filterable", "virtual", "size", "rounded", "fillMode"], outputs: ["valueChange", "selectionChange", "filterChange", "open", "opened", "close", "closed", "focus", "blur", "inputFocus", "inputBlur", "escape"], exportAs: ["kendoComboBox"] }, { kind: "directive", type: ToolbarComboBoxDirective, selector: "[kendoPDFViewerComboBox]" }, { kind: "directive", type: ItemTemplateDirective, selector: "[kendoDropDownListItemTemplate],[kendoComboBoxItemTemplate],[kendoAutoCompleteItemTemplate],[kendoMultiSelectItemTemplate]" }, { kind: "directive", type: NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: ToolbarComponent, decorators: [{
            type: Component,
            args: [{
                    selector: '[kendoPDFViewerToolbar]',
                    providers: [ToolbarNavigationService],
                    template: `
        <ng-container *ngFor="let tool of tools">
            <ng-container [ngSwitch]="tool">
                <kendo-toolbar-input-wrapper
                    *ngSwitchCase="'pager'"
                    kendoPDFViewerToolbarFocusable
                    [toolbarTool]="pager">
                    <kendo-datapager
                        #pager
                        [attr.aria-controls]="pagesContainerId"
                        [attr.aria-label]="messageFor('page') + ' ' + (skip + 1) + ' ' + messageFor('of') + total"
                        [class.k-disabled]="disabledTools"
                        [navigable]="true"
                        [pageSize]="pageSize"
                        [skip]="skip"
                        [total]="total"
                        [pageSizeValues]="false"
                        [info]="false"
                        [type]="pagerType"
                        (pageChange)="pageChange.emit($event)">
                        <kendo-datapager-messages
                            [firstPage]="messageFor('pagerFirstPage')"
                            [previousPage]="messageFor('pagerPreviousPage')"
                            [nextPage]="messageFor('pagerNextPage')"
                            [lastPage]="messageFor('pagerLastPage')"
                            [inputLabel]="messageFor('pagerInputLabel')"
                            [pageNumberInputTitle]="messageFor('pagerInputTitle')"
                            [of]="messageFor('pagerOf')"
                            [page]="messageFor('pagerPage')"></kendo-datapager-messages>
                    </kendo-datapager>
                </kendo-toolbar-input-wrapper>
                <span
                    *ngSwitchCase="'spacer'"
                    class="k-spacer"></span>
                <kendo-buttongroup
                    *ngSwitchCase="'zoomInOut'"
                    [attr.aria-controls]="pagesContainerId"
                    class="k-button-group-flat k-toolbar-button-group"
                    [navigable]="false">
                    <button
                        type="button"
                        kendoButton
                        fillMode="flat"
                        kendoPDFViewerToolbarFocusable
                        icon="zoom-out"
                        [disabled]="disabledTools || zoomOutDisabled"
                        [svgIcon]="zoomOutIcon"
                        [attr.title]="messageFor('zoomOutTitle')"
                        [attr.aria-label]="messageFor('zoomOutTitle')"
                        (click)="zoomOut.emit()"></button>
                    <button
                        type="button"
                        kendoButton
                        fillMode="flat"
                        kendoPDFViewerToolbarFocusable
                        icon="zoom-in"
                        [disabled]="disabledTools || zoomInDisabled"
                        [svgIcon]="zoomInIcon"
                        [attr.title]="messageFor('zoomInTitle')"
                        [attr.aria-label]="messageFor('zoomInTitle')"
                        (click)="zoomIn.emit()"></button>
                </kendo-buttongroup>
                <kendo-toolbar-input-wrapper
                    *ngSwitchCase="'zoom'"
                    kendoPDFViewerToolbarFocusable
                    [toolbarTool]="combobox">
                    <kendo-combobox
                        #combobox
                        kendoPDFViewerComboBox
                        class="k-toolbar-combobox"
                        fillMode="flat"
                        [attr.aria-controls]="pagesContainerId"
                        [tabindex]="-1"
                        [data]="zoomOptionsData"
                        [disabled]="disabledTools"
                        [placeholder]="messageFor('zoomInputPlaceholder')"
                        textField="displayValue"
                        valueField="id"
                        [value]="zoomLevelChooserValue"
                        [allowCustom]="true"
                        [valueNormalizer]="valueNormalizer"
                        [clearButton]="false"
                        (valueChange)="onZoomLevelChooserValueChange($event)">
                        <ng-template kendoComboBoxItemTemplate let-dataItem>
                            {{ dataItem.type ? messageFor('f' + dataItem.type.slice(1)) : dataItem.text }}
                        </ng-template>
                    </kendo-combobox>
                </kendo-toolbar-input-wrapper>
                <kendo-buttongroup
                    *ngSwitchCase="'selection'"
                    [attr.aria-controls]="pagesContainerId"
                    [navigable]="false"
                    class="k-button-group-flat k-toolbar-button-group"
                    selection="single">
                    <button
                        type="button"
                        kendoButton
                        kendoPDFViewerToolbarFocusable
                        fillMode="flat"
                        icon="pointer"
                        [toggleable]="true"
                        [svgIcon]="pointerIcon"
                        [attr.title]="messageFor('selectionTitle')"
                        [attr.aria-label]="messageFor('selectionTitle')"
                        (click)="selectionEnabled.emit()"></button>
                    <button
                        type="button"
                        kendoButton
                        kendoPDFViewerToolbarFocusable
                        fillMode="flat"
                        icon="hand"
                        [svgIcon]="handIcon"
                        [toggleable]="true"
                        [selected]="true"
                        [attr.title]="messageFor('panningTitle')"
                        [attr.aria-label]="messageFor('panningTitle')"
                        (click)="panningEnabled.emit()"></button>
                </kendo-buttongroup>
                <button
                    *ngSwitchCase="'search'"
                    type="button"
                    kendoPDFViewerToolbarFocusable
                    kendoButton
                    class="k-toolbar-button"
                    fillMode="flat"
                    icon="search"
                    [disabled]="disabledTools"
                    [attr.title]="messageFor('searchTitle')"
                    [attr.aria-label]="messageFor('searchTitle')"
                    aria-haspopup="dialog"
                    [svgIcon]="searchIcon"
                    (click)="search.emit()"></button>
                <button
                    *ngSwitchCase="'open'"
                    type="button"
                    fillMode="flat"
                    kendoPDFViewerToolbarFocusable
                    kendoButton
                    class="k-toolbar-button"
                    fillMode="flat"
                    icon="folder-open"
                    [svgIcon]="folderOpenIcon"
                    [attr.title]="messageFor('openTitle')"
                    [attr.aria-label]="messageFor('openTitle')"
                    [attr.aria-controls]="pagesContainerId"
                    (click)="fileSelectEl?.nativeElement.click()">
                </button>
                <button
                    *ngSwitchCase="'download'"
                    type="button"
                    fillMode="flat"
                    kendoPDFViewerToolbarFocusable
                    kendoButton
                    class="k-toolbar-button"
                    icon="download"
                    [svgIcon]="downloadIcon"
                    [disabled]="disabledTools"
                    [attr.title]="messageFor('downloadTitle')"
                    [attr.aria-label]="messageFor('downloadTitle')"
                    (click)="download.emit()"></button>
                <button
                    *ngSwitchCase="'print'"
                    type="button"
                    fillMode="flat"
                    kendoPDFViewerToolbarFocusable
                    kendoButton
                    class="k-toolbar-button"
                    icon="print"
                    [svgIcon]="printIcon"
                    [disabled]="disabledTools"
                    [attr.title]="messageFor('printTitle')"
                    [attr.aria-label]="messageFor('printTitle')"
                    (click)="print.emit()"></button>
            </ng-container>
        </ng-container>
        <input
            #fileSelectEl
            *ngIf="tools?.indexOf('open') > -1;"
            type="file"
            [style.display]="'none'"
            aria-hidden="true"
            accept=".pdf, .PDF"
            (change)="onFileSelect($event)" />
    `,
                    standalone: true,
                    imports: [NgFor, NgSwitch, NgSwitchCase, ToolbarInputWrapperComponent, ToolbarFocusableDirective, PagerComponent, CustomMessagesComponent, ButtonGroupComponent, ButtonComponent, ComboBoxComponent, ToolbarComboBoxDirective, ItemTemplateDirective, NgIf]
                }]
        }], ctorParameters: function () { return [{ type: i1.LocalizationService }, { type: i2.ToolbarNavigationService }]; }, propDecorators: { toolbarClasses: [{
                type: HostBinding,
                args: ['class.k-toolbar']
            }, {
                type: HostBinding,
                args: ['class.k-toolbar-md']
            }, {
                type: HostBinding,
                args: ['class.k-toolbar-flat']
            }], fileSelectEl: [{
                type: ViewChild,
                args: ['fileSelectEl']
            }], zoomLevel: [{
                type: Input
            }], calculatedComboBoxValue: [{
                type: Input
            }], skip: [{
                type: Input
            }], pageSize: [{
                type: Input
            }], total: [{
                type: Input
            }], zoomInDisabled: [{
                type: Input
            }], zoomOutDisabled: [{
                type: Input
            }], disabledTools: [{
                type: Input
            }], zoomLevelChooserValue: [{
                type: Input
            }], zoomOptionsData: [{
                type: Input
            }], pagesContainerId: [{
                type: Input
            }], tools: [{
                type: Input
            }], fileSelect: [{
                type: Output
            }], fileSelectStart: [{
                type: Output
            }], fileSelectError: [{
                type: Output
            }], download: [{
                type: Output
            }], selectionEnabled: [{
                type: Output
            }], panningEnabled: [{
                type: Output
            }], pageChange: [{
                type: Output
            }], zoomIn: [{
                type: Output
            }], zoomOut: [{
                type: Output
            }], zoomLevelChange: [{
                type: Output
            }], print: [{
                type: Output
            }], search: [{
                type: Output
            }] } });
