/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { PreventableEvent } from "@progress/kendo-angular-common";
import { PDFViewerContext } from "./pdfviewer-context";
import { SaveOptions } from "@progress/kendo-file-saver";
/**
 * Represents the event data object of the `LoadEvent`.
 */
export interface PDFViewerLoadEvent {
    /**
     * Represents the loaded `PDF.js` document, its pages, and their DOM element wrapper.
     */
    context: PDFViewerContext;
}
/**
 * Represents the event data object of the `ErrorEvent`.
 */
export interface PDFViewerErrorEvent {
    /**
     * Provides the original `Error` object.
     */
    error: Error;
    /**
     * Represents the loaded `PDF.js` document, its pages, and their DOM element wrapper.
     */
    context: PDFViewerContext;
}
/**
 * Represents the arguments for the PDFViewer `download` event. The event fires when the user clicks the **Download** tool. Canceling the event prevents the download.
 */
export declare class PDFViewerDownloadEvent extends PreventableEvent {
    /**
     * Provides the Blob object to be saved.
     */
    readonly blob: Blob;
    /**
     * Provides the file name for saving.
     */
    readonly fileName: string;
    /**
     * Provides the save options.
     */
    readonly saveOptions: SaveOptions;
    /**
     * Represents the loaded `PDF.js` document, its pages, and their DOM element wrapper.
     */
    readonly context: PDFViewerContext;
    /**
     * @hidden
     */
    constructor(blob: Blob, fileName: string, saveOptions: SaveOptions, context: PDFViewerContext);
}
/**
 * Represents the data object of the `PDFViewerPageChangeEvent`
 */
export interface PDFViewerPageChangeEvent {
    /**
     * Provides the previous active page before triggering the event.
     */
    previousPage: number;
    /**
     * Provides the current active page after triggering the event.
     */
    currentPage: number;
}
/**
 * Represents the data object of the `PDFViewerZoomChangeEvent`
 */
export interface PDFViewerZoomChangeEvent {
    /**
     * Provides the previous zoom level.
     */
    previousZoomLevel: number;
    /**
     * Provides the current zoom level.
     */
    currentZoomLevel: number;
}
