/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { ElementRef, EventEmitter } from '@angular/core';
import { LocalizationService } from '@progress/kendo-angular-l10n';
import { PageChangeEvent, PagerType } from '@progress/kendo-angular-pager';
import { SVGIcon } from '@progress/kendo-svg-icons';
import { ToolbarNavigationService } from './toolbar-navigation.service';
import { PDFViewerTool } from '../models/toolbar-tool';
import { ZoomLevel } from '../models/zoom-level';
import { Observable } from 'rxjs';
import * as i0 from "@angular/core";
/**
 * @hidden
 */
export declare class ToolbarComponent {
    private localization;
    private navigationService;
    toolbarClasses: boolean;
    fileSelectEl: ElementRef;
    zoomLevel: ZoomLevel;
    calculatedComboBoxValue: {
        text: string;
        displayValue: any;
        value: any;
    };
    skip: number;
    pageSize: number;
    total: number;
    zoomInDisabled: boolean;
    zoomOutDisabled: boolean;
    disabledTools: boolean;
    zoomLevelChooserValue: ZoomLevel;
    zoomOptionsData: ZoomLevel[];
    pagesContainerId: string;
    tools: PDFViewerTool[];
    fileSelect: EventEmitter<string | ArrayBuffer>;
    fileSelectStart: EventEmitter<any>;
    fileSelectError: EventEmitter<any>;
    download: EventEmitter<any>;
    selectionEnabled: EventEmitter<any>;
    panningEnabled: EventEmitter<any>;
    pageChange: EventEmitter<PageChangeEvent>;
    zoomIn: EventEmitter<any>;
    zoomOut: EventEmitter<any>;
    zoomLevelChange: EventEmitter<ZoomLevel>;
    print: EventEmitter<any>;
    search: EventEmitter<any>;
    zoomInIcon: SVGIcon;
    zoomOutIcon: SVGIcon;
    handIcon: SVGIcon;
    pointerIcon: SVGIcon;
    searchIcon: SVGIcon;
    folderOpenIcon: SVGIcon;
    downloadIcon: SVGIcon;
    printIcon: SVGIcon;
    pagerType: PagerType;
    constructor(localization: LocalizationService, navigationService: ToolbarNavigationService);
    messageFor(key: string): string;
    onFileSelect(e: any): void;
    onZoomLevelChooserValueChange(zoomLevel: ZoomLevel): void;
    focus(): void;
    valueNormalizer: (text: Observable<string>) => Observable<{
        value: number;
        displayValue: string;
        text: string;
    }>;
    static ɵfac: i0.ɵɵFactoryDeclaration<ToolbarComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<ToolbarComponent, "[kendoPDFViewerToolbar]", never, { "zoomLevel": { "alias": "zoomLevel"; "required": false; }; "calculatedComboBoxValue": { "alias": "calculatedComboBoxValue"; "required": false; }; "skip": { "alias": "skip"; "required": false; }; "pageSize": { "alias": "pageSize"; "required": false; }; "total": { "alias": "total"; "required": false; }; "zoomInDisabled": { "alias": "zoomInDisabled"; "required": false; }; "zoomOutDisabled": { "alias": "zoomOutDisabled"; "required": false; }; "disabledTools": { "alias": "disabledTools"; "required": false; }; "zoomLevelChooserValue": { "alias": "zoomLevelChooserValue"; "required": false; }; "zoomOptionsData": { "alias": "zoomOptionsData"; "required": false; }; "pagesContainerId": { "alias": "pagesContainerId"; "required": false; }; "tools": { "alias": "tools"; "required": false; }; }, { "fileSelect": "fileSelect"; "fileSelectStart": "fileSelectStart"; "fileSelectError": "fileSelectError"; "download": "download"; "selectionEnabled": "selectionEnabled"; "panningEnabled": "panningEnabled"; "pageChange": "pageChange"; "zoomIn": "zoomIn"; "zoomOut": "zoomOut"; "zoomLevelChange": "zoomLevelChange"; "print": "print"; "search": "search"; }, never, never, true, never>;
}
